#if TARGET_OS_IOS

#import "ScreenCaptureController.h"
#import "ScreenCapturer.h"
#import "SocketConnection.h"

NSString *const kRTCScreensharingVideoSocketFD = @"rtc_SSFD_video";
NSString *const kRTCScreensharingAudioSocketFD = @"rtc_SSFD_audio";
NSString *const kRTCAppGroupIdentifier = @"RTCAppGroupIdentifier";

@interface ScreenCaptureController ()

@property(nonatomic, retain) ScreenCapturer *capturer;

@end

@interface ScreenCaptureController (CapturerEventsDelegate)<CapturerEventsDelegate>
- (void)capturerDidEnd:(RTCVideoCapturer *)capturer;
@end

@interface ScreenCaptureController (Private)

@property(nonatomic, readonly) NSString *appGroupIdentifier;

@end

@implementation ScreenCaptureController

- (instancetype)initWithCapturer:(nonnull ScreenCapturer *)capturer {
    self = [super init];
    if (self) {
        self.capturer = capturer;
    }

    return self;
}

- (void)dealloc {
    [self.capturer stopCapture];
}

- (void)startCapture {
    if (!self.appGroupIdentifier) {
        return;
    }

    self.capturer.eventsDelegate = self;
    
    NSString *videoSocketFilePath = [self filePathForApplicationGroupIdentifier:self.appGroupIdentifier 
                                                                     socketType:@"video"];
    SocketConnection *videoConnection = [[SocketConnection alloc] initWithFilePath:videoSocketFilePath];
    
    NSString *audioSocketFilePath = [self filePathForApplicationGroupIdentifier:self.appGroupIdentifier 
                                                                     socketType:@"audio"];
    SocketConnection *audioConnection = [[SocketConnection alloc] initWithFilePath:audioSocketFilePath];
    
    [self.capturer startCaptureWithVideoConnection:videoConnection 
                                  audioConnection:audioConnection];
}

- (void)stopCapture {
    [self.capturer stopCapture];
}

// MARK: CapturerEventsDelegate Methods

- (void)capturerDidEnd:(RTCVideoCapturer *)capturer {
    [self.eventsDelegate capturerDidEnd:capturer];
}

// MARK: Private Methods

- (NSString *)appGroupIdentifier {
    NSDictionary *infoDictionary = [[NSBundle mainBundle] infoDictionary];
    return infoDictionary[kRTCAppGroupIdentifier];
}

- (NSString *)filePathForApplicationGroupIdentifier:(nonnull NSString *)identifier 
                                        socketType:(NSString *)socketType {
    NSURL *sharedContainer =
        [[NSFileManager defaultManager] containerURLForSecurityApplicationGroupIdentifier:identifier];
    
    NSString *socketSuffix = [socketType isEqualToString:@"video"] ? 
                            kRTCScreensharingVideoSocketFD : 
                            kRTCScreensharingAudioSocketFD;
    
    NSString *socketFilePath = [[sharedContainer URLByAppendingPathComponent:socketSuffix] path];
    
    return socketFilePath;
}

@end

#endif